@@ -18,9 +18,12 @@ from pyro.util import ignore_jit_warnings
 
 
 def fit_mobster(data, K, tail=1, purity=0.96,alpha_prior_concentration = 5, alpha_prior_rate = 10, number_of_trials_clonal_mean=500.,number_of_trials_k=300.,
-         prior_lims_clonal=[0.1, 100000.], prior_lims_k=[0.1, 100000.], stopping = ELBO_stopping_criteria, lr = 0.05, max_it = 5000, e = 0.001, compile = False, CUDA = False):
+         prior_lims_clonal=[0.1, 100000.], prior_lims_k=[0.1, 100000.], stopping = ELBO_stopping_criteria, lr = 0.05,
+                max_it = 5000, e = 0.001, compile = False, CUDA = False, seed = 3):
 
 
+    pyro.set_rng_seed(seed)
+
     if CUDA:
         torch.set_default_tensor_type('torch.cuda.FloatTensor')
 
